# Extract objects on one single layer
# Write result to another gdsii file

import gdspy
import sys

if len(sys.argv) >= 3:
  print ("Input file: ", sys.argv[1], ", layer to extract: ", sys.argv[2])

  input_name = sys.argv[1]
  layer_to_extract = int(sys.argv[2])

  output_name = "exctracted_" + str(layer_to_extract) + ".gds"
    
  input_library = gdspy.GdsLibrary(infile='trafo.gds')
  output_library = gdspy.GdsLibrary()


  # get top level cells
  toplevel_cell_list = input_library.top_level()

  # iterate over top level cells
  for cell in toplevel_cell_list:
    print("________________\n", cell)
    
    # flatten hierarchy below this cell
    cell.flatten(single_layer=None, single_datatype=None, single_texttype=None)
    
    # get layers used in cell
    used_layers = cell.get_layers()
    
    # check if layer-to-extract is used in cell 
    if layer_to_extract in used_layers:
      print("Layer exists in cell")
      out_cell = output_library.new_cell(cell.name)
      
      # iterate over layer-purpose pairs (by_spec=true)
      # do not descend into cell references (depth=0)
      LPPpolylist = cell.get_polygons(by_spec=True, depth=0)
      for LPP in LPPpolylist:
        layer = LPP[0]
        purpose = LPP[1]
        
        # now get polygons for this one layer-purpose-pair
        if layer==layer_to_extract:
          layerpolygons = LPPpolylist[(layer, purpose)]
          for polypoints in layerpolygons:
            # print(polypoints)
      
            # write to output
            poly = gdspy.Polygon(polypoints, layer, purpose)
            out_cell.add(poly)

      
  # write library with filtered objects
  print("Writing output file ", output_name)
  output_library.write_gds(output_name)  

else:
  print ("Usage: gdspy_extractsinglelayer <input.gds> <layernum>")

  
  
